==> haskell-pandoc_3.1.3.orig.tar.gz: pandoc-3.1.3/test/command/8764.md <==
```
% pandoc -f html -t opendocument
<table>
  <tbody>
    <tr>
      <th>Header</th>
      <td>Normal cell (column 2)</td>
      <td>Normal cell (column 3)</td>
    </tr>
    <tr>
      <td>Normal cell (column 1)</td>
      <td>Normal cell (column 2)</td>
      <td>Normal cell (column 3)</td>
    </tr>
  </tbody>
</table>
^D
<table:table table:name="Table1" table:style-name="Table1">
  <table:table-column table:style-name="Table1.A" />
  <table:table-column table:style-name="Table1.B" />
  <table:table-column table:style-name="Table1.C" />
  <table:table-row>
    <table:table-cell table:style-name="TableRowCell" office:value-type="string">
      <text:p text:style-name="Table_20_Heading">Header</text:p>
    </table:table-cell>
    <table:table-cell table:style-name="TableRowCell" office:value-type="string">
      <text:p text:style-name="Table_20_Contents">Normal cell (column
      2)</text:p>
    </table:table-cell>
    <table:table-cell table:style-name="TableRowCell" office:value-type="string">
      <text:p text:style-name="Table_20_Contents">Normal cell (column
      3)</text:p>
    </table:table-cell>
  </table:table-row>
  <table:table-row>
    <table:table-cell table:style-name="TableRowCell" office:value-type="string">
      <text:p text:style-name="Table_20_Heading">Normal cell (column
      1)</text:p>
    </table:table-cell>
    <table:table-cell table:style-name="TableRowCell" office:value-type="string">
      <text:p text:style-name="Table_20_Contents">Normal cell (column
      2)</text:p>
    </table:table-cell>
    <table:table-cell table:style-name="TableRowCell" office:value-type="string">
      <text:p text:style-name="Table_20_Contents">Normal cell (column
      3)</text:p>
    </table:table-cell>
  </table:table-row>
</table:table>
```

==> haskell-pandoc_3.1.11.1.orig.tar.gz: pandoc-3.1.11.1/test/command/8764.md <==
```
% pandoc -f html -t opendocument
<table>
  <tbody>
    <tr>
      <th>Header</th>
      <td>Normal cell (column 2)</td>
      <td>Normal cell (column 3)</td>
    </tr>
    <tr>
      <td>Normal cell (column 1)</td>
      <td>Normal cell (column 2)</td>
      <td>Normal cell (column 3)</td>
    </tr>
  </tbody>
</table>
^D
<table:table table:name="Table1" table:style-name="Table1">
  <table:table-column table:style-name="Table1.A" />
  <table:table-column table:style-name="Table1.B" />
  <table:table-column table:style-name="Table1.C" />
  <table:table-row>
    <table:table-cell table:style-name="TableRowCell" office:value-type="string">
      <text:p text:style-name="Table_20_Contents">Header</text:p>
    </table:table-cell>
    <table:table-cell table:style-name="TableRowCell" office:value-type="string">
      <text:p text:style-name="Table_20_Contents">Normal cell (column
      2)</text:p>
    </table:table-cell>
    <table:table-cell table:style-name="TableRowCell" office:value-type="string">
      <text:p text:style-name="Table_20_Contents">Normal cell (column
      3)</text:p>
    </table:table-cell>
  </table:table-row>
  <table:table-row>
    <table:table-cell table:style-name="TableRowCell" office:value-type="string">
      <text:p text:style-name="Table_20_Contents">Normal cell (column
      1)</text:p>
    </table:table-cell>
    <table:table-cell table:style-name="TableRowCell" office:value-type="string">
      <text:p text:style-name="Table_20_Contents">Normal cell (column
      2)</text:p>
    </table:table-cell>
    <table:table-cell table:style-name="TableRowCell" office:value-type="string">
      <text:p text:style-name="Table_20_Contents">Normal cell (column
      3)</text:p>
    </table:table-cell>
  </table:table-row>
</table:table>
```
